@@ -208,7 +208,7 @@ const TelepathyClient = new Lang.Class({
                                                        : 'unavailable'));
 
         this._accountsMonitor.enabledAccounts.forEach(a => {
-            if (a.presence_type == Tp.ConnectionPresenceType.AVAILABLE &&
+            if (a.requested_presence_type == Tp.ConnectionPresenceType.AVAILABLE &&
                 a.connection_status == Tp.ConnectionStatus.CONNECTED)
                 this._onAccountStatusChanged(this._accountsMonitor, a);
             else
@@ -303,13 +303,14 @@ const TelepathyClient = new Lang.Class({
         let username = settings.get_string('identify-username') ||
                        params.username.deep_unpack();
         let contactName = settings.get_string('identify-botname');
+        let command = settings.get_string('identify-command');
         this._requestChannel(account, Tp.HandleType.CONTACT, contactName,
             (channel) => {
                 if (!channel)
                     return;
 
                 let room = this._roomManager.lookupRoomByChannel(channel);
-                room.send_identify_message_async(username, password, (r, res) => {
+                room.send_identify_message_async(command, username, password, (r, res) => {
                     try {
                         r.send_identify_message_finish(res);
                     } catch(e) {
@@ -432,6 +433,11 @@ const TelepathyClient = new Lang.Class({
         else
             settings.set_string('identify-botname', data.botname);
 
+        if (data.command == 'identify')
+            settings.reset('identify-command');
+        else
+            settings.set_string('identify-command', data.command);
+
         settings.set_string('identify-username', data.username);
     },
 
@@ -473,10 +479,8 @@ const TelepathyClient = new Lang.Class({
         context.accept();
     },
 
-    vfunc_observe_channels: function() {
-        let [account, connection,
-             channels, op, requests, context] = arguments;
-
+    vfunc_observe_channels: function(account, connection, channels,
+                                     op, requests, context) {
         this._processRequest(context, connection, channels, Lang.bind(this,
             function(channel) {
                 if (this._isAuthChannel(channel))
@@ -499,10 +503,8 @@ const TelepathyClient = new Lang.Class({
             }));
     },
 
-    vfunc_handle_channels: function() {
-        let [account, connection,
-             channels, satisfied, userTime, context] = arguments;
-
+    vfunc_handle_channels: function(account, connection, channels,
+                                    satisfied, userTime, context) {
         let [present, ] = Tp.user_action_time_should_present(userTime);
 
         this._processRequest(context, connection, channels, Lang.bind(this,
@@ -552,11 +554,12 @@ const TelepathyClient = new Lang.Class({
         return notification;
     },
 
-    _onIdentifySent: function(room, username, password) {
+    _onIdentifySent: function(room, command, username, password) {
         let accountPath = room.account.object_path;
 
         let data = {
             botname: room.channel.target_contact.alias,
+            command: command,
             username: username || room.channel.connection.self_contact.alias,
             password: password
         };
